==> mx-locale_24.11.01.tar.xz: BUILD/translations/mx-locale_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>プログラム名(_N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>ヘルプの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <source>System Locale</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="vanished">システムロケール</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>プッシュボタン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>現在のシステム言語:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>すべてのロケール関係の項目を現在の言語に合わせる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>ロケールのカテゴリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>数値</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>順序</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>通貨</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>用紙の規格</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>氏名</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>電話番号</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>計量単位</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>ロケール管理</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>利用可能なロケールの全リスト</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Enabled</source>
        <translation>有効なロケール（チェックで無効化）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Disabled</source>
        <translation>無効なロケール（チェックで有効化）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>使用中のロケール以外をすべて無効にする</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>ロケールリストを既定にリセット</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>システムの既定で使用する言語以外の MX マニュアルを削除する</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>変更は次回ログイン時に有効となります</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Locale</source>
        <translation>MX ロケールマネージャ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Program for changing language and locale categories</source>
        <translation>言語やロケールに関する項目の設定を管理するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>現在のロケール: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>すべて</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>使用中のロケールは無効にできません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>有効なロケール: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Could not open %1</source>
        <translation>%1 を開くことができません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Locales enabled: %1</source>
        <translation>利用可能なロケール: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Updating locales, please wait</source>
        <translation>ロケールを更新してるのでお待ちください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Removing packages, please wait</source>
        <translation>パッケージの削除中なのでお待ちください</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <location filename="../about.cpp" line="46"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX ロケールマネージャは、MX Linux 用のロケール管理ツールです</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Show only language selection tab.</source>
        <translation>言語選択タブのみを表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Show all locale categories.</source>
        <translation>すべてのロケール項目を表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <location filename="../main.cpp" line="79"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>希望する言語がここに表示されていない場合は、「ロケール管理」タブで有効にしてください</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX ロケールマネージャ</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation>%1 を開くことができません</translation>
    </message>
</context>
</TS>

==> mx-locale_25.4.tar.xz: BUILD/translations/mx-locale_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>プログラム名(_N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Display help </source>
        <translation>ヘルプの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>PushButton</source>
        <translation>プッシュボタン</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>Current System Language:</source>
        <translation>現在のシステム言語:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>System Language</source>
        <extracomment> language selection, also default for locale subvariables if not otherwise defined</extracomment>
        <translation>システム言語</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="187"/>
        <source>Set all locale categories to current language</source>
        <translation>すべてのロケール関係の項目を現在の言語に合わせる</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Locale Categories</source>
        <extracomment>defines individual subvariables for locale</extracomment>
        <translation>ロケールのカテゴリ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <source>Numeric</source>
        <translation>数値</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Time</source>
        <translation>時刻</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Collate</source>
        <translation>順序</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Currency</source>
        <translation>通貨</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Messages</source>
        <translation>メッセージ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Paper Size</source>
        <translation>用紙の規格</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <source>Name Style</source>
        <translation>氏名</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Telephone</source>
        <translation>電話番号</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Measurement</source>
        <translation>計量単位</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Locale Management</source>
        <extracomment>Tab to manage generation of locale caches</extracomment>
        <translation>ロケール管理</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <location filename="../mainwindow.ui" line="469"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>All</source>
        <extracomment>elements of filter box</extracomment>
        <translation>利用可能なロケールの全リスト</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Enabled</source>
        <translation>有効なロケール（チェックで無効化）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Disabled</source>
        <translation>無効なロケール（チェックで有効化）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Disable all locales except the one in use</source>
        <extracomment>disables generation of any locale except on that is currently in use</extracomment>
        <translation>使用中のロケール以外をすべて無効にする</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="455"/>
        <source>Reset locale list to default</source>
        <translation>ロケールリストを既定にリセット</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>MX マニュアルはこの言語版以外すべて削除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Changes go into effect on login</source>
        <translation>変更は次回ログイン時に有効となります</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>MX Locale</source>
        <translation>MX ロケールマネージャ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>Version: </source>
        <translation>バージョン：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>Program for changing language and locale categories</source>
        <translation>言語やロケールに関する項目の設定を管理するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>%1 Help</source>
        <translation>%1 ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Locale in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <comment>shows the current system locale, in bold</comment>
        <translation>現在のロケール: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>All</source>
        <comment>all as in everything</comment>
        <translation>すべて</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Can&apos;t disable locale in use</source>
        <comment>message that the chosen locale cannot be disabled because it is in active usage</comment>
        <translation>使用中のロケールは無効にできません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>Locales enabled: %1</source>
        <comment>label for a numerical count of enabled and available locales</comment>
        <translation>有効なロケール: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Could not open %1</source>
        <translation>%1 を開くことができません</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Locales enabled: %1</source>
        <translation>利用可能なロケール: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Updating locales, please wait</source>
        <translation>ロケールを更新してるのでお待ちください</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Remove Manuals</source>
        <translation>マニュアルを削除する</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>No manuals to remove.</source>
        <translation>削除可能なマニュアルは存在しません。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Removing packages, please wait</source>
        <translation>パッケージの削除中なのでお待ちください</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>MX Locale is a tool used for managing locale settings in MX Linux</source>
        <translation>MX ロケールマネージャは、MX Linux 用のロケール管理ツールです</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Show only language selection tab.</source>
        <translation>言語選択タブのみを表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Show all locale categories.</source>
        <translation>すべてのロケール項目を表示します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>root としてログインしているようです。このプログラムを使用するには、一度ログアウトして通常のユーザとしてログインしてください。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>このプログラムは管理者権限で実行してください。</translation>
    </message>
</context>
<context>
    <name>chooseDialog</name>
    <message>
        <location filename="../choosedialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="48"/>
        <source>search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../choosedialog.ui" line="58"/>
        <source>If your desired language is not listed here, enable it in &quot;Locale management&quot; tab</source>
        <translation>希望する言語がここに表示されていない場合は、「ロケール管理」タブで有効にしてください</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="25"/>
        <source>MX Locale</source>
        <comment>name of application</comment>
        <translation>MX ロケールマネージャ</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="40"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../choosedialog.cpp" line="41"/>
        <source>Could not open %1</source>
        <comment>message that a file could not be opened, file takes place of %1</comment>
        <translation type="unfinished">%1 を開くことができません</translation>
    </message>
    <message>
        <source>Could not open %1</source>
        <comment>message that a file could not be open, file takes place of %1</comment>
        <translation type="vanished">%1 を開くことができません</translation>
    </message>
</context>
</TS>
